package de.frajul.endlessroll.main.screens;

import android.widget.LinearLayout;
import android.widget.TableRow;

import de.frajul.endlessroll.R;
import de.frajul.endlessroll.entities.shapes.PlayerShape;
import de.frajul.endlessroll.entities.shapes.PlayerShapeButtonOnClickListener;
import de.frajul.endlessroll.main.GameActivity;
import de.frajul.endlessroll.views.PlayerShapeButton;
import de.frajul.endlessroll.views.TopBar;

/**
 * Created by Julian on 08.07.2016.
 */
public class PlayerShapeShopScreen extends Screen<LinearLayout> implements PlayerShapeButtonOnClickListener {

    private PlayerShapeButton activeButton;

    private TopBar topBar;
    private TableRow topRow;
    private TableRow bottomRow;

    public PlayerShapeShopScreen(GameActivity gameActivity) {
        super(ScreenType.SHAPE_SHOP, gameActivity, R.layout.shape_shop);
        topBar = super.createTopBar(R.id.shape_shop_topbar);
        topRow = (TableRow) layout.findViewById(R.id.shape_shop_topRow);
        bottomRow = (TableRow) layout.findViewById(R.id.shape_shop_bottomRow);
    }

    private void createViews() {
        topRow.removeAllViews();
        bottomRow.removeAllViews();
        int i = 0;
        int totalShapes = PlayerShape.values().length;
        for (PlayerShape playerShape : PlayerShape.values()) {
            PlayerShapeButton button = new PlayerShapeButton(gameActivity, playerShape, this);
            if (i < totalShapes / 2)
                topRow.addView(button.getView());
            else
                bottomRow.addView(button.getView());

            if (playerShape.equals(gameActivity.getUser().getCurrentPlayerShape())) {
                this.activeButton = button;
                button.startRotating();
            }

            i++;
        }
    }

    @Override
    public void prepareToBeShown() {
        createViews();
        topBar.update();
    }

    @Override
    public void onBackKeyDown() {
        flipToCaller();
    }

    @Override
    public void onClick(PlayerShapeButton button) {
        activeButton.stopRotating();
        activeButton = button;
        activeButton.startRotating();
        gameActivity.getUser().setCurrentPlayerShape(button.getPlayerShape());
    }
}
